@@ -57,6 +57,7 @@ class UseCaseOutcome:
             "duration_(seconds)": self.duration(et),
         }
 
+        self._normalise_logs()
         self.create_uco_record(self._normalise_keys(p_load), siem_record)
 
     def duration(self, end_time: DateTime) -> float:
@@ -96,22 +97,18 @@ class UseCaseOutcome:
             }
         )
 
-    @staticmethod
-    def _normalise_keys(d: dict) -> dict:
-        # returns the dict with _ replaced with spaces and each word capitalised.
-        return {key.replace("_", " ").title(): value for key, value in d.items()}
-
-    @staticmethod
-    def _normalise_logs(logs: list) -> list:
+    def _normalise_logs(self):
         # returns the list of logs that are passed in, with each dict containing the same keys. Required for UI widget
         keys = set([
-            key for item in logs for key in item.keys()
+            key for item in self.logs for key in item.keys()
         ])
 
-        for log in logs:
+        for log in self.logs:
             for key in keys:
                 if key not in log:
                     log[key] = ""
 
-        # logs is mutable
-        return logs
+    @staticmethod
+    def _normalise_keys(d: dict) -> dict:
+        # returns the dict with _ replaced with spaces and each word capitalised.
+        return {key.replace("_", " ").title(): value for key, value in d.items()}
